@@ -14,7 +14,7 @@ This library is published under the MIT License.
 """
 
 from .core.CartographySelector import CartographySelector
-from .core.Drifter import Drifter
+from .core.CrossFader import CrossFader
 from .core.Fader import Fader
 from .core.Hocketer import Hocketer
 from .core.LeafLooper import LeafLooper
@@ -26,6 +26,8 @@ from .core.Shuffler import Shuffler
 from .core.TenneySelector import TenneySelector
 from .core.WindowLooper import WindowLooper
 
+from .indicators.TimeSignature import TimeSignature
+
 from .score.ArtificialHarmonic import ArtificialHarmonic
 from .score.HarmonicNote import HarmonicNote
 from .score.LeafDynMaker import LeafDynMaker
@@ -34,18 +36,15 @@ from .utilities.inspect import Inspection
 from .utilities.inspect import inspect
 from .utilities.mutate import Mutation
 from .utilities.mutate import mutate
-from .utilities.simplify_time_signature_ratio import (
-    simplify_time_signature_ratio,
-)
 
 
 __author__ = "Gilberto Agostinho <gilbertohasnofb@gmail.com>"
-__version__ = "0.8.12"
+__version__ = "0.8.14"
 __all__ = [
     '__author__',
     '__version__',
     'CartographySelector',
-    'Drifter',
+    'CrossFader',
     'Fader',
     'Hocketer',
     'LeafLooper',
@@ -56,6 +55,7 @@ __all__ = [
     'Shuffler',
     'TenneySelector',
     'WindowLooper',
+    'TimeSignature',
     'ArtificialHarmonic',
     'HarmonicNote',
     'LeafDynMaker',
@@ -63,5 +63,4 @@ __all__ = [
     'inspect',
     'Mutation',
     'mutate',
-    'simplify_time_signature_ratio',
 ]
